This S4 class is used internally to hold common arguments passed between functions to simplify the function signatures and reduce redundant argument passing.
byAggregation/grouping specification
callThe original function call
calling_functionThe name of the calling function (comparisons, predictions, hypotheses)
comparisonComparison function specification
crossBoolean flag for cross-contrasts
dfThe degrees of freedom
epsEpsilon value for numerical derivatives
jacobianThe jacobian matrix or NULL
jacobian_methodString naming the differentiation path which produced the jacobian: "analytic", "analytic+numeric_stage", "numeric", "custom", or NULL
modelThe fitted model object
modeldataThe model data frame
newdataThe new data frame for predictions
typeThe sanitized type from sanitize_type()
vcov_modelThe variance-covariance matrix
wtsThe weights specification