plot_predictions() is an alias to plot_predictions()This alias is kept for backward compatibility.
plot_cap(
model,
condition = NULL,
by = NULL,
newdata = NULL,
type = NULL,
vcov = NULL,
conf_level = 0.95,
transform = NULL,
points = 0,
rug = FALSE,
gray = FALSE,
draw = TRUE,
...
)A ggplot2 object or data frame (if draw=FALSE)
Model object
Conditional predictions
Character vector (max length 3): Names of the predictors to display.
Named list (max length 3): List names correspond to predictors. List elements can be:
Numeric vector
Function which returns a numeric vector or a set of unique categorical values
Shortcut strings for common reference values: "minmax", "quartile", "threenum"
1: x-axis. 2: color/shape. 3: facets.
Numeric variables in positions 2 and 3 are summarized by Tukey's five numbers ?stats::fivenum
Marginal predictions
Character vector (max length 3): Names of the categorical predictors to marginalize across.
1: x-axis. 2: color. 3: facets.
Grid of predictor values at which we evaluate the slopes.
NULL (default): Unit-level slopes for each observed value in the original dataset.
data frame: Unit-level slopes for each row of the newdata data frame.
datagrid() call to specify a custom grid of regressors. For example:
newdata = datagrid(cyl = c(4, 6)): cyl variable equal to 4 and 6 and other regressors fixed at their means or modes.
See the Examples section and the datagrid() documentation.
string:
"mean": Marginal Effects at the Mean. Slopes when each predictor is held at its mean or mode.
"median": Marginal Effects at the Median. Slopes when each predictor is held at its median or mode.
"marginalmeans": Marginal Effects at Marginal Means. See Details section below.
"tukey": Marginal Effects at Tukey's 5 numbers.
"grid": Marginal Effects on a grid of representative numbers (Tukey's 5 numbers and unique values of categorical predictors).
string indicates the type (scale) of the predictions used to
compute contrasts or slopes. This can differ based on the model
type, but will typically be a string such as: "response", "link", "probs",
or "zero". When an unsupported string is entered, the model-specific list of
acceptable values is returned in an error message. When type is NULL, the
default value is used. This default is the first model-related row in
the marginaleffects:::type_dictionary dataframe.
Type of uncertainty estimates to report (e.g., for robust standard errors). Acceptable values:
FALSE: Do not compute standard errors. This can speed up computation considerably.
TRUE: Unit-level standard errors using the default vcov(model) variance-covariance matrix.
String which indicates the kind of uncertainty estimates to return.
Heteroskedasticity-consistent: "HC", "HC0", "HC1", "HC2", "HC3", "HC4", "HC4m", "HC5". See ?sandwich::vcovHC
Heteroskedasticity and autocorrelation consistent: "HAC"
Mixed-Models degrees of freedom: "satterthwaite", "kenward-roger"
Other: "NeweyWest", "KernHAC", "OPG". See the sandwich package documentation.
One-sided formula which indicates the name of cluster variables (e.g., ~unit_id). This formula is passed to the cluster argument of the sandwich::vcovCL function.
Square covariance matrix
Function which returns a covariance matrix (e.g., stats::vcov(model))
numeric value between 0 and 1. Confidence level to use to build a confidence interval.
A function applied to unit-level adjusted predictions and confidence intervals just before the function returns results. For bayesian models, this function is applied to individual draws from the posterior distribution, before computing summaries.
Number between 0 and 1 which controls the transparency of raw data points. 0 (default) does not display any points.
TRUE displays tick marks on the axes to mark the distribution of raw data.
FALSE grayscale or color plot
TRUE returns a ggplot2 plot. FALSE returns a data.frame of the underlying data.
Additional arguments are passed to the predict() method
supplied by the modeling package.These arguments are particularly useful
for mixed-effects or bayesian models (see the online vignettes on the
marginaleffects website). Available arguments can vary from model to
model, depending on the range of supported arguments by each modeling
package. See the "Model-Specific Arguments" section of the
?marginaleffects documentation for a non-exhaustive list of available
arguments.
Some model types allow model-specific arguments to modify the nature of
marginal effects, predictions, marginal means, and contrasts. Please report
other package-specific predict() arguments on Github so we can add them to
the table below.
https://github.com/vincentarelbundock/marginaleffects/issues
| Package | Class | Argument | Documentation |
brms | brmsfit | ndraws | brms::posterior_predict |
re_formula | brms::posterior_predict | ||
lme4 | merMod | re.form | lme4::predict.merMod |
allow.new.levels | lme4::predict.merMod | ||
glmmTMB | glmmTMB | re.form | glmmTMB::predict.glmmTMB |
allow.new.levels | glmmTMB::predict.glmmTMB | ||
zitype | glmmTMB::predict.glmmTMB | ||
mgcv | bam | exclude | mgcv::predict.bam |
robustlmm | rlmerMod | re.form | robustlmm::predict.rlmerMod |
allow.new.levels | robustlmm::predict.rlmerMod | ||
MCMCglmm | MCMCglmm | ndraws |
mod <- lm(mpg ~ hp + wt, data = mtcars)
plot_predictions(mod, condition = "wt")
mod <- lm(mpg ~ hp * wt * am, data = mtcars)
plot_predictions(mod, condition = c("hp", "wt"))
plot_predictions(mod, condition = list("hp", wt = "threenum"))
plot_predictions(mod, condition = list("hp", wt = range))
Run the code above in your browser using DataLab